Index: src/gpu/GrGeometryBuffer.h |
diff --git a/src/gpu/GrGeometryBuffer.h b/src/gpu/GrGeometryBuffer.h |
index adccbf80e4aca4c69ec5f516860fef695d9d2e1c..56a6cae3fb08f32f8e3e7fcbbb276ba81620b858 100644 |
--- a/src/gpu/GrGeometryBuffer.h |
+++ b/src/gpu/GrGeometryBuffer.h |
@@ -48,7 +48,7 @@ public: |
* Note that buffer mapping does not go through GrContext and therefore is |
* not serialized with other operations. |
* |
* @return a pointer to the data or NULL if the map fails. |
*/ |
void* map() { return (fMapPtr = this->onMap()); } |
@@ -60,14 +60,14 @@ public: |
void unmap() { |
SkASSERT(fMapPtr); |
this->onUnmap(); |
- fMapPtr = NULL; |
+ fMapPtr = nullptr; |
} |
/** |
* Returns the same ptr that map() returned at time of map or NULL if the |
* is not mapped. |
* |
* @return ptr to mapped buffer data or NULL if buffer is not mapped. |
*/ |
void* mapPtr() const { return fMapPtr; } |
@@ -101,7 +101,7 @@ public: |
protected: |
GrGeometryBuffer(GrGpu* gpu, size_t gpuMemorySize, bool dynamic, bool cpuBacked) |
: INHERITED(gpu, kCached_LifeCycle) |
- , fMapPtr(NULL) |
+ , fMapPtr(nullptr) |
, fGpuMemorySize(gpuMemorySize) |
, fDynamic(dynamic) |
, fCPUBacked(cpuBacked) {} |
@@ -48,7 +48,7 @@ public: |
* not serialized with other operations. |
* |
- * @return a pointer to the data or NULL if the map fails. |
+ * @return a pointer to the data or nullptr if the map fails. |
*/ |
void* map() { return (fMapPtr = this->onMap()); } |
@@ -60,14 +60,14 @@ public: |
} |
/** |
- * Returns the same ptr that map() returned at time of map or NULL if the |
+ * Returns the same ptr that map() returned at time of map or nullptr if the |
* is not mapped. |
* |
@@ -60,14 +60,14 @@ public: |
* is not mapped. |
* |
- * @return ptr to mapped buffer data or NULL if buffer is not mapped. |
+ * @return ptr to mapped buffer data or nullptr if buffer is not mapped. |
*/ |
void* mapPtr() const { return fMapPtr; } |